"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; } function _nullishCoalesce(lhs, rhsFn) { if (lhs != null) { return lhs; } else { return rhsFn(); } } function _optionalChain(ops) { let lastAccessLHS = undefined; let value = ops[0]; let i = 1; while (i < ops.length) { const op = ops[i]; const fn = ops[i + 1]; i += 2; if ((op === 'optionalAccess' || op === 'optionalCall') && value == null) { return undefined; } if (op === 'access' || op === 'optionalAccess') { lastAccessLHS = value; value = fn(value); } else if (op === 'call' || op === 'optionalCall') { value = fn((...args) => value.call(lastAccessLHS, ...args)); lastAccessLHS = undefined; } } return value; }// src/util/dateTime.ts
var createDate = (hours, minutes) => {
  const date = /* @__PURE__ */ new Date();
  date.setHours(hours, minutes, 0, 0);
  return date;
};
var MS_PER_DAY = 1e3 * 60 * 60 * 24;
var createDateFromNowWithOffset = (offsetInDays) => {
  const currentDate = /* @__PURE__ */ new Date();
  const offsetInMilliseconds = offsetInDays * MS_PER_DAY;
  const newDate = new Date(currentDate.getTime() + offsetInMilliseconds);
  return newDate;
};

// src/util/fs/fsDelete.ts
var _fsextra = require('fs-extra'); var _fsextra2 = _interopRequireDefault(_fsextra);
var fsDeleteDirectory = async (directoryPath) => {
  if (!_fsextra.existsSync.call(void 0, directoryPath))
    return true;
  await _fsextra2.default.rm(directoryPath, { recursive: true, force: true });
  return true;
};
var fsDeleteFile = async (filePath) => _fsextra2.default.promises.rm(filePath, { force: true }).then(
  () => true,
  () => true
);

// src/util/fs/fsDownloadFromUrl.ts
var _axios = require('axios'); var _axios2 = _interopRequireDefault(_axios);
var _filetype = require('file-type');

// src/util/fs/fsWrite.ts

var writeToFile = async (directory, content, fileName) => {
  await _fsextra.ensureDir.call(void 0, directory);
  const filePath = `${directory}/${fileName}`;
  await _fsextra.writeFile.call(void 0, filePath, content);
  return filePath;
};

// src/convert/bytesToMb.ts
var bytesToMb = (bytes) => Math.round(bytes / 1024 / 1024);

// src/convert/epochToDate.ts
var epochToDate = (epoch) => new Date(Number(epoch) * 1e3);

// src/util/fs/fsDownloadFromUrl.ts
var downloadFileFromUrl = async ({
  url,
  fileName,
  directoryPath,
  limit
}) => {
  if (!url || !directoryPath) {
    throw new Error("Url and DirectoryPath are required");
  }
  const fileLimit = {
    minBytes: 0,
    maxBytes: 100 * 1024 * 1024,
    // 100 MB
    ...limit
  };
  const { data, headers } = await _axios2.default.get(url, {
    responseType: "arraybuffer",
    maxBodyLength: fileLimit.maxBytes
  });
  const contentLength = parseInt(_nullishCoalesce(headers["content-length"], () => ( "0")), 10);
  if (isNaN(contentLength) || contentLength <= 0 || contentLength > fileLimit.maxBytes || contentLength < fileLimit.minBytes) {
    throw new Error(
      `Media size is invalid. Size should be between ${fileLimit.maxBytes} and ${fileLimit.minBytes} bytes or between ${bytesToMb(
        fileLimit.maxBytes
      )} and ${bytesToMb(fileLimit.minBytes)}`
    );
  }
  const fileType = await _filetype.fileTypeFromBuffer.call(void 0, data);
  if (!fileType || !isValidMediaType(fileType.mime)) {
    throw new Error("Invalid media type. Should be image, video, pdf or doc");
  }
  const fileNameString = _nullishCoalesce(fileName, () => ( `${Date.now()}-${Math.random()}.${fileType.ext}`));
  const filePath = await writeToFile(
    directoryPath,
    data,
    fileNameString
  );
  const fileData = {
    path: filePath,
    size: contentLength,
    sizeInMB: `${(contentLength / 1024 / 1024).toFixed(2)} MB`,
    fileType: fileType.mime,
    fileTypeExt: fileType.ext,
    fileName: fileNameString,
    url,
    createdAt: /* @__PURE__ */ new Date()
  };
  return fileData;
};
var isValidMediaType = (mediaType) => {
  return mediaType.startsWith("image/") || mediaType.startsWith("video/") || mediaType.startsWith("application/pdf") || mediaType.startsWith("application/msword") || mediaType.startsWith(
    "application/vnd.openxmlformats-officedocument.wordprocessingml.document"
  );
};

// src/util/fs/fsJSON.ts

var readJSONFile = async (filePath) => {
  const fileContent = await _fsextra2.default.readFile(filePath, "utf8");
  try {
    return JSON.parse(fileContent);
  } catch (error) {
    throw error;
  }
};
var writeJsonToFile = async (filePath, jsonData, options) => {
  if (typeof filePath !== "string" || filePath.length === 0) {
    throw new Error("Invalid filePath");
  }
  if (jsonData === null || jsonData === void 0) {
    throw new Error("Invalid jsonData");
  }
  let data;
  if (typeof jsonData === "string") {
    try {
      data = JSON.parse(jsonData);
    } catch (err) {
      throw new Error("Invalid jsonData");
    }
  } else {
    data = jsonData;
  }
  try {
    await _fsextra.writeJson.call(void 0, filePath, data, options);
    return true;
  } catch (error) {
    throw new Error(
      `Failed to write JSON file: ${filePath}, error: ${error.message}`
    );
  }
};

// src/isValid/isValidIpAddress.ts
var isValidIpAddress = (ipAddress) => {
  if (typeof ipAddress !== "string") {
    throw new TypeError("ipAddress must be a string");
  }
  const ipAddressRegex = /^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/;
  return ipAddressRegex.test(ipAddress);
};

// src/isValid/isValidJson.ts
var isValidJson = (json) => {
  try {
    if (typeof json !== "string") {
      return false;
    }
    JSON.parse(json);
  } catch (e) {
    return false;
  }
  return true;
};

// src/isValid/isValidUrl.ts
var defaultAllowed = ["https:", "http:"];
var allowedLocalHosts = ["localhost", "127.0.0.1"];
var isValidUrl = (url, allowedProtocols) => {
  try {
    if (typeof url !== "string") {
      throw new TypeError("url must be a string");
    }
    if (url.length === 0)
      return false;
    if (allowedLocalHosts.includes(url))
      return true;
    if (url.includes(".") && !url.includes("://"))
      return isValidUrl(`http://${url}`);
    const fccUrl = new URL(url);
    const mapProtocols = _nullishCoalesce(_optionalChain([allowedProtocols, 'optionalAccess', _ => _.map, 'call', _2 => _2((p) => p.endsWith(":") ? p : `${p}:`)]), () => ( []));
    const checkProtocols = [...defaultAllowed, ...mapProtocols].map(
      (p) => p.toLowerCase()
    );
    const check = checkProtocols.includes(fccUrl.protocol) || checkProtocols.includes(fccUrl.protocol.toLowerCase());
    if (check)
      return true;
    return false;
  } catch (error) {
    return false;
  }
};














exports.bytesToMb = bytesToMb; exports.createDate = createDate; exports.createDateFromNowWithOffset = createDateFromNowWithOffset; exports.downloadFileFromUrl = downloadFileFromUrl; exports.epochToDate = epochToDate; exports.fsDeleteDirectory = fsDeleteDirectory; exports.fsDeleteFile = fsDeleteFile; exports.fsReadJSONFile = readJSONFile; exports.fsWriteJsonToFile = writeJsonToFile; exports.fsWriteToFile = writeToFile; exports.isValidIpAddress = isValidIpAddress; exports.isValidJson = isValidJson; exports.isValidUrl = isValidUrl;
//# sourceMappingURL=index.cjs.map